#
# spec file for package vpcs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vpcs
Version:        0.8.2
Release:        1.10
Summary:        Virtual PC Simulator
License:        BSD-2-Clause
Group:          System/Emulators/Other
URL:            https://github.com/GNS3/vpcs
Source0:        https://github.com/GNS3/vpcs/archive/v%{version}.tar.gz

%description
The VPCS can simulate up to 9 PCs. You can ping/traceroute them, or ping/traceroute
the other hosts/routers from the virtual PCs when you study the Cisco routers in
the Dynamips. VPCS is not the traditional PC, it is just a program running on the
Linux or Windows, and only few network commands can be used in it. But VPCS can
give you a big hand when you study the Cisco devices in the Dynamips. VPCS can
replace the routers or VMware boxes which are used as PCs in the Dynamips network.

Try VPCS, it can save your CPU/Memory. It is very small.

Now, VPCS can be run in udp or ether mode. In the udp mode, VPCS sends or receives
the packets via udp. In the ether mode, via /dev/tap, not support on the Windows.

%prep
%autosetup -p1

%build
cd src
rm getopt.*
export CFLAGS="%{optflags} -D_GNU_SOURCE -fno-strict-aliasing -fcommon"
%make_build -f Makefile.linux CPUTYPE=%_target_cpu

%install
install -D -m0755 src/vpcs %{buildroot}%{_bindir}/vpcs
install -D -m0644 man/vpcs.1 %{buildroot}%{_mandir}/man1/vpcs.1

%files
%license COPYING
%doc readme.txt
%{_bindir}/vpcs
%{_mandir}/man1/vpcs.1%{ext_man}

%changelog
* Fri Jan 28 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 0.8.2:
  * Fix IPv6 router advertisement parsing to accept options out-of-order
  * fix failure to receive DHCP offer
  * Remove possibility to run commands on host
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.1:
  * switch to fork of vpcs which includes patches wrote by various people from
    the community
- remove 0001-revert-from-r124.patch (upstream)
- drop vpcs-0.8-no-static.patch (obsolete)
* Mon Jun  8 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon to workaround gcc10 errors (boo#1160244)
* Wed Jun  3 2020 Martin Hauke <mardnh@gmx.de>
- Specfile cleanup
- Add patch:
  * 0001-revert-from-r124.patch
    Fix bug "enter" is executed after the second typed character
    See: https://github.com/GNS3/vpcs/issues/10
* Mon Jan 15 2018 crrodriguez@opensuse.org
- vpcs-0.8-no-static.patch: extend so binaries are not stripped.
  fixes debuginfo generation
- remove bundled getopt implementation, fixes conflict with
  glibc headers and build in TW.
* Fri Nov 20 2015 andrea@opensuse.org
- new upstream version 0.8
  * Support IPv6 fragmentation
  * Support DNS AAAA record
  * Add an option to disable the relay function from the command line
- removed vpcs-0.5b0-no-static.patch and replaced by vpcs-0.8-no-static.patch
* Thu Jun  4 2015 andrea@opensuse.org
- new upstream version 0.6.1
  * Turn off the relay feature because it is conflicting with GNS3
* Wed Dec 10 2014 andrea@opensuse.org
- vpcs shouldn't require dynamips
* Thu Nov 20 2014 andrea@opensuse.org
- new upstream version 0.6
  * fix: commands with more than 20 arguments will cause core dump
  * display the file name while running 'save' to save the configuration
  * command string begins with '#' or ';' is considered as comment in CLI
  * renew the dhcp4 lease automatically
  * support ip fragmentation
  * fix: use MAC of gateway while replying in the background
  * fix: history list overflow
* Fri Jul  4 2014 andrea@opensuse.org
- changed project homepage
* Tue Jul  1 2014 andrea@opensuse.org
- New upstream version 0.5b2
  * fix: using getenv+access to the real path of VPCS.
  * patch for Debian GNU/kFreeBSD from Daniel Lintott
    flush out the output buffer while running 'echo ...'
  * increase the maxinum number of tcp sessions and decrease tcp keep alive time
  * fix: arp table, the source ether address is not saved
* Mon May 19 2014 andrea@opensuse.org
- New upstream version 0.5b1
  * Support for a specified number of vpc instances (between 1 and 9)
  * Support for TAP device name (only with 1 VPC instance)
- Changed project home page
* Tue Mar 25 2014 andrea@opensuse.org
- spec file clean up
* Sun Mar 23 2014 andrea@opensuse.org
- new upstream version 0.5b0
  * support to hypervisor mode
- added vpcs-0.5b0-no-static.patch to avoid static library linking
* Mon Jan  7 2013 andrea@opensuse.org
- new upstream version 0.4b2
  * support DNS
  * support 'dump' packets
  * add 'rlogin' command to connect the remote host
  * support daemon mode
  * more at http://blog.chinaunix.net/space.php?uid=20020608&do=blog&id=3274792
- removed man page now in upstream code
* Thu Jan 12 2012 andrea@opensuse.org
- New upstream version 0.3
  * vpcs is now opensource (BSD)
* Tue Apr 19 2011 andrea@opensuse.org
- New package
